pub struct PubsubClient {}Expand description
A client for subscribing to messages from the RPC server.
See the module documentation.
Implementations
Sourceimpl PubsubClient
impl PubsubClient
Sourcepub fn account_subscribe<R>(
request: R,
pubkey: &Address,
config: Option<RpcAccountInfoConfig>,
) -> Result<(PubsubClientSubscription<Response<UiAccount>>, Receiver<Response<UiAccount>>), PubsubClientError>where
R: IntoClientRequest,
pub fn account_subscribe<R>(
request: R,
pubkey: &Address,
config: Option<RpcAccountInfoConfig>,
) -> Result<(PubsubClientSubscription<Response<UiAccount>>, Receiver<Response<UiAccount>>), PubsubClientError>where
R: IntoClientRequest,
Subscribe to account events.
Receives messages of type UiAccount when an account’s lamports or data changes.
RPC Reference
This method corresponds directly to the accountSubscribe RPC method.
Sourcepub fn block_subscribe<R>(
request: R,
filter: RpcBlockSubscribeFilter,
config: Option<RpcBlockSubscribeConfig>,
) -> Result<(PubsubClientSubscription<Response<RpcBlockUpdate>>, Receiver<Response<RpcBlockUpdate>>), PubsubClientError>where
R: IntoClientRequest,
pub fn block_subscribe<R>(
request: R,
filter: RpcBlockSubscribeFilter,
config: Option<RpcBlockSubscribeConfig>,
) -> Result<(PubsubClientSubscription<Response<RpcBlockUpdate>>, Receiver<Response<RpcBlockUpdate>>), PubsubClientError>where
R: IntoClientRequest,
Subscribe to block events.
Receives messages of type RpcBlockUpdate when a block is confirmed or finalized.
This method is disabled by default. It can be enabled by passing
--rpc-pubsub-enable-block-subscription to agave-validator.
RPC Reference
This method corresponds directly to the blockSubscribe RPC method.
Sourcepub fn logs_subscribe<R>(
request: R,
filter: RpcTransactionLogsFilter,
config: RpcTransactionLogsConfig,
) -> Result<(PubsubClientSubscription<Response<RpcLogsResponse>>, Receiver<Response<RpcLogsResponse>>), PubsubClientError>where
R: IntoClientRequest,
pub fn logs_subscribe<R>(
request: R,
filter: RpcTransactionLogsFilter,
config: RpcTransactionLogsConfig,
) -> Result<(PubsubClientSubscription<Response<RpcLogsResponse>>, Receiver<Response<RpcLogsResponse>>), PubsubClientError>where
R: IntoClientRequest,
Subscribe to transaction log events.
Receives messages of type RpcLogsResponse when a transaction is committed.
RPC Reference
This method corresponds directly to the logsSubscribe RPC method.
Sourcepub fn program_subscribe<R>(
request: R,
pubkey: &Address,
config: Option<RpcProgramAccountsConfig>,
) -> Result<(PubsubClientSubscription<Response<RpcKeyedAccount>>, Receiver<Response<RpcKeyedAccount>>), PubsubClientError>where
R: IntoClientRequest,
pub fn program_subscribe<R>(
request: R,
pubkey: &Address,
config: Option<RpcProgramAccountsConfig>,
) -> Result<(PubsubClientSubscription<Response<RpcKeyedAccount>>, Receiver<Response<RpcKeyedAccount>>), PubsubClientError>where
R: IntoClientRequest,
Subscribe to program account events.
Receives messages of type RpcKeyedAccount when an account owned
by the given program changes.
RPC Reference
This method corresponds directly to the programSubscribe RPC method.
Sourcepub fn vote_subscribe<R>(
request: R,
) -> Result<(PubsubClientSubscription<RpcVote>, Receiver<RpcVote>), PubsubClientError>where
R: IntoClientRequest,
pub fn vote_subscribe<R>(
request: R,
) -> Result<(PubsubClientSubscription<RpcVote>, Receiver<RpcVote>), PubsubClientError>where
R: IntoClientRequest,
Subscribe to vote events.
Receives messages of type RpcVote when a new vote is observed. These
votes are observed prior to confirmation and may never be confirmed.
This method is disabled by default. It can be enabled by passing
--rpc-pubsub-enable-vote-subscription to agave-validator.
RPC Reference
This method corresponds directly to the voteSubscribe RPC method.
Sourcepub fn root_subscribe<R>(
request: R,
) -> Result<(PubsubClientSubscription<u64>, Receiver<u64>), PubsubClientError>where
R: IntoClientRequest,
pub fn root_subscribe<R>(
request: R,
) -> Result<(PubsubClientSubscription<u64>, Receiver<u64>), PubsubClientError>where
R: IntoClientRequest,
Subscribe to root events.
Receives messages of type Slot when a new root is set by the
validator.
RPC Reference
This method corresponds directly to the rootSubscribe RPC method.
Sourcepub fn signature_subscribe<R>(
request: R,
signature: &Signature,
config: Option<RpcSignatureSubscribeConfig>,
) -> Result<(PubsubClientSubscription<Response<RpcSignatureResult>>, Receiver<Response<RpcSignatureResult>>), PubsubClientError>where
R: IntoClientRequest,
pub fn signature_subscribe<R>(
request: R,
signature: &Signature,
config: Option<RpcSignatureSubscribeConfig>,
) -> Result<(PubsubClientSubscription<Response<RpcSignatureResult>>, Receiver<Response<RpcSignatureResult>>), PubsubClientError>where
R: IntoClientRequest,
Subscribe to transaction confirmation events.
Receives messages of type RpcSignatureResult when a transaction
with the given signature is committed.
This is a subscription to a single notification. It is automatically cancelled by the server once the notification is sent.
RPC Reference
This method corresponds directly to the signatureSubscribe RPC method.
Sourcepub fn slot_subscribe<R>(
request: R,
) -> Result<(PubsubClientSubscription<SlotInfo>, Receiver<SlotInfo>), PubsubClientError>where
R: IntoClientRequest,
pub fn slot_subscribe<R>(
request: R,
) -> Result<(PubsubClientSubscription<SlotInfo>, Receiver<SlotInfo>), PubsubClientError>where
R: IntoClientRequest,
Subscribe to slot events.
Receives messages of type SlotInfo when processing of a slot begins.
RPC Reference
This method corresponds directly to the slotSubscribe RPC method.
Sourcepub fn slot_updates_subscribe<R>(
request: R,
handler: impl Fn(SlotUpdate) + Send + 'static,
) -> Result<PubsubClientSubscription<SlotUpdate>, PubsubClientError>where
R: IntoClientRequest,
pub fn slot_updates_subscribe<R>(
request: R,
handler: impl Fn(SlotUpdate) + Send + 'static,
) -> Result<PubsubClientSubscription<SlotUpdate>, PubsubClientError>where
R: IntoClientRequest,
Subscribe to slot update events.
Receives messages of type SlotUpdate when various updates to a slot occur.
Note that this method operates differently than other subscriptions:
instead of sending the message to a receiver on a channel, it accepts a
handler callback that processes the message directly. This processing
occurs on another thread.
RPC Reference
This method corresponds directly to the slotUpdatesSubscribe RPC method.