pub enum CommitmentLevel {
Processed,
Confirmed,
Finalized,
}Expand description
An attribute of a slot. It describes how finalized a block is at some point in time. For example, a slot is said to be at the max level immediately after the cluster recognizes the block at that slot as finalized. When querying the ledger state, use lower levels of commitment to report progress and higher levels to ensure state changes will not be rolled back.
Variants
Processed
The highest slot of the heaviest fork processed by the node. Ledger state at this slot is not derived from a confirmed or finalized block, but if multiple forks are present, is from the fork the validator believes is most likely to finalize.
Confirmed
The highest slot that has been voted on by supermajority of the cluster, ie. is confirmed. Confirmation incorporates votes from gossip and replay. It does not count votes on descendants of a block, only direct votes on that block, and upholds “optimistic confirmation” guarantees in release 1.3 and onwards.
Finalized
The highest slot having reached max vote lockout, as recognized by a supermajority of the cluster.