pub enum OptionalContext<T> {
Context(Response<T>),
NoContext(T),
}Expand description
Wrapper for rpc return types of methods that provide responses both with and without context. Main purpose of this is to fix methods that lack context information in their return type, without breaking backwards compatibility.
Variants
Implementations
Sourceimpl<T> OptionalContext<T>
impl<T> OptionalContext<T>
pub fn parse_value(self) -> T