Module solana_client::tpu_client [−][src]
Structs
| TpuClient | Client which sends transactions directly to the current leader’s TPU port over UDP. The client uses RPC to determine the current leader and fetch node contact info |
| TpuClientConfig | Config params for |
Enums
| TpuSenderError |
Constants
| DEFAULT_FANOUT_SLOTS | Default number of slots used to build TPU socket fanout set |
| MAX_FANOUT_SLOTS | Maximum number of slots used to build TPU socket fanout set |