TpuClient

Struct TpuClient 

pub struct TpuClient<P, M, C> { /* private fields */ }
Client which sends transactions directly to the current leader’s TPU port over UDP. The client uses RPC to determine the current leader and fetch node contact info This is just a thin wrapper over the “BackendTpuClient”, use that directly for more efficiency.

Implementations

Source

impl<P, M, C> TpuClient<P, M, C>
where P: ConnectionPool<NewConnectionConfig = C>, M: ConnectionManager<ConnectionPool = P, NewConnectionConfig = C>, C: NewConnectionConfig,

pub fn send_transaction(&self, transaction: &Transaction) -> bool

Serialize and send transaction to the current and upcoming leader TPUs according to fanout size

pub fn send_wire_transaction(&self, wire_transaction: Vec<u8>) -> bool

Send a wire transaction to the current and upcoming leader TPUs according to fanout size

pub fn try_send_transaction( &self, transaction: &VersionedTransaction, ) -> TransportResult<()>

Serialize and send transaction to the current and upcoming leader TPUs according to fanout size Returns the last error if all sends fail

pub fn try_send_transaction_batch( &self, transactions: &[VersionedTransaction], ) -> TransportResult<()>

Serialize and send a batch of transactions to the current and upcoming leader TPUs according to fanout size Returns the last error if all sends fail

pub fn try_send_wire_transaction( &self, wire_transaction: Vec<u8>, ) -> TransportResult<()>

Send a wire transaction to the current and upcoming leader TPUs according to fanout size Returns the last error if all sends fail

Source

impl TpuClient<QuicPool, QuicConnectionManager, QuicConfig>

pub fn new( rpc_client: Arc<RpcClient>, websocket_url: &str, config: TpuClientConfig, ) -> Result<Self>

Create a new client that disconnects when dropped

Source

impl<P, M, C> TpuClient<P, M, C>
where P: ConnectionPool<NewConnectionConfig = C>, M: ConnectionManager<ConnectionPool = P, NewConnectionConfig = C>, C: NewConnectionConfig,

pub fn new_with_connection_cache( rpc_client: Arc<RpcClient>, websocket_url: &str, config: TpuClientConfig, connection_cache: Arc<BackendConnectionCache<P, M, C>>, ) -> Result<Self>

Create a new client that disconnects when dropped

pub fn send_and_confirm_messages_with_spinner<T: Signers + ?Sized>( &self, messages: &[Message], signers: &T, ) -> Result<Vec<Option<TransactionError>>>

pub fn rpc_client(&self) -> &RpcClient